@@ -29,11 +29,11 @@ main (int   argc,
 {
   g_autoptr (GcalApplication) app;
 
-#ifdef ENABLE_NLS
   bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
-#endif
+
+  g_set_application_name (_("Calendar"));
 
   app = gcal_application_new ();
 
